% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geom-curling.R
\name{geom_curling}
\alias{geom_curling}
\title{Generate a \code{ggplot2} instance containing a curling sheet for a specified
league}
\usage{
geom_curling(
  league,
  display_range = "full",
  sheet_updates = list(),
  color_updates = list(),
  rotation = 0,
  x_trans = 0,
  y_trans = 0,
  sheet_units = NULL,
  xlims = NULL,
  ylims = NULL
)
}
\arguments{
\item{league}{The league for which to draw the surface. This is
case-insensitive}

\item{display_range}{A case-insensitive string indicating the display range
to use for the plot. The default is \code{"full"}, which will be returned
when either an invalid or no value is passed to the function.

The possible display ranges are:

\describe{
\item{\code{"full"}}{The full sheet. This is the default}
\item{\code{"in_bounds_only"}}{The full in-bounds area of the sheet}
\item{\code{"in bounds only"}}{The full in-bounds area of the sheet}
\item{\code{"house"}}{
A single house, which defaults to the top house in TV view
}
}}

\item{sheet_updates}{A list of updates to the sheet's parameters. These will
overwrite the parameters of the league}

\item{color_updates}{A list of updates to the sheet's default colors, which
are set by \code{\link[=curling_features_set_colors]{curling_features_set_colors()}}}

\item{rotation}{An angle, given in degrees, through which the plot should be
rotated}

\item{x_trans}{The amount that the \code{x} coordinates are to be shifted. By
convention, the +\code{x} axis extends from the center of the sheet towards
the right-hand goal when viewing the sheet in TV View}

\item{y_trans}{The amount that the \code{y} coordinates are to be shifted. By
convention, the +\code{y} axis extends from the center of the sheet towards
the top of the sheet when viewing the sheet in TV view}

\item{sheet_units}{The units with which to draw the sheet. The default is
\code{NULL}, which will apply the rule-book specified units}

\item{xlims}{The limits on the final display in the \code{x} direction. The
default is \code{NULL}, which will utilize the \code{xlims} specified by
the \code{display_range} parameter}

\item{ylims}{The limits on the final display in the \code{y} direction. The
default is \code{NULL}, which will utilize the \code{ylims} specified by
the \code{display_range} parameter}
}
\value{
A \code{ggplot2} instance with a full-surface representation of a
curling sheet
}
\description{
Generate a \code{ggplot2} instance containing a curling sheet for a specified
league
}
\examples{
\dontrun{
  geom_curling(league = "wcf", rotation = 270, display_range = "house")
  geom_curling(league = "wcf", sheet_units = "ft")
}
}
